unsigned int getbit(unsigned char bit,unsigned int which);
unsigned char setbit(unsigned char bit,unsigned int which,unsigned int what);
int strip8bit(char * chain, unsigned int sizeofchain);
